@@ -44,4 +44,26 @@ __PACKAGE__->add_columns(
 
 __PACKAGE__->set_primary_key("id");
 
+=head1 NAME
+
+TaskPipe::SchemaTemplate_Project_SP500::Result::Company - schema template for the SP500 project C<company> table
+
+=head1 DESCRIPTION
+
+Schema Template for the error table
+
+=head1 AUTHOR
+
+Tom Gracey <tomgracey@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) Tom Gracey 2018
+
+TaskPipe is free software, licensed under
+
+    The GNU Public License Version 3
+
+=cut
+
 1;
