@@ -52,4 +52,29 @@ has poll_for => (is => 'rw', isa => 'ArrayRef[Str]', default => sub{[
 
 1;|);
 
+=head1 NAME
+
+TaskPipe::Template_Task_SP500ScrapeQuote - template for the Scrape_Quote task in the SP500 sample project
+
+=head1 DESCRIPTION
+
+Template for the Scrape_Quote task in the SP500 sample project
+
+=head1 AUTHOR
+
+Tom Gracey <tomgracey@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) Tom Gracey 2018
+
+TaskPipe is free software, licensed under
+
+    The GNU Public License Version 3
+
+=cut
+
+
+
+
 1;
