@@ -5,7 +5,7 @@ with 'MooseX::ConfigCascade';
 
 =head1 NAME
 
-TaskPipe::UserAgentManager::Settings
+TaskPipe::UserAgentManager::Settings - settings for TaskPipe::UserAgentManger
 
 =head1 DESCRIPTION
 
